You are viewing a plain text version of this content. The canonical link for it is here.
Posted to notifications@shardingsphere.apache.org by pa...@apache.org on 2020/10/27 11:23:30 UTC

[shardingsphere] branch master updated: Rename SQLParserConfiguration to SQLParserFacade (#7935)

This is an automated email from the ASF dual-hosted git repository.

panjuan pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/shardingsphere.git


The following commit(s) were added to refs/heads/master by this push:
     new 19597b9  Rename SQLParserConfiguration to SQLParserFacade (#7935)
19597b9 is described below

commit 19597b9dad4e4ea8a2459215734f1eabf24505ec
Author: Liang Zhang <te...@163.com>
AuthorDate: Tue Oct 27 19:23:03 2020 +0800

    Rename SQLParserConfiguration to SQLParserFacade (#7935)
    
    * Rename SQLParserConfiguration.getDatabaseType
    
    * Rename SQLParserFacade
---
 ...erConfiguration.java => MySQLParserFacade.java} |  8 ++---
 ....shardingsphere.sql.parser.spi.SQLParserFacade} |  2 +-
 ...rConfiguration.java => OracleParserFacade.java} |  8 ++---
 ....shardingsphere.sql.parser.spi.SQLParserFacade} |  2 +-
 ...figuration.java => PostgreSQLParserFacade.java} |  8 ++---
 ....shardingsphere.sql.parser.spi.SQLParserFacade} |  2 +-
 ...erConfiguration.java => SQL92ParserFacade.java} |  8 ++---
 ....shardingsphere.sql.parser.spi.SQLParserFacade} |  2 +-
 ...nfiguration.java => SQLServerParserFacade.java} |  8 ++---
 ....shardingsphere.sql.parser.spi.SQLParserFacade} |  2 +-
 ...nRegistry.java => SQLParserFacadeRegistry.java} | 34 +++++++++++-----------
 .../sql/parser/core/parser/SQLParserFactory.java   |  8 ++---
 ...rserConfiguration.java => SQLParserFacade.java} | 10 +++----
 .../sql/parser/spi/SQLVisitorFacade.java           |  8 ++---
 14 files changed, 55 insertions(+), 55 deletions(-)

diff --git a/shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-mysql/src/main/resources/META-INF/services/org.apache.shardingsphere.sql.parser.spi.SQLParserConfiguration b/shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-mysql/src/main/resources/META-INF/services/org.apache.shardingsphere.sql.parser.spi.SQLParserFacade
similarity index 92%
rename from shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-mysql/src/main/resources/META-INF/services/org.apache.shardingsphere.sql.parser.spi.SQLParserConfiguration
rename to shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-mysql/src/main/resources/META-INF/services/org.apache.shardingsphere.sql.parser.spi.SQLParserFacade
index 992ab62..5841cc7 100644
--- a/shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-mysql/src/main/resources/META-INF/services/org.apache.shardingsphere.sql.parser.spi.SQLParserConfiguration
+++ b/shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-mysql/src/main/resources/META-INF/services/org.apache.shardingsphere.sql.parser.spi.SQLParserFacade
@@ -15,4 +15,4 @@
 # limitations under the License.
 #
 
-org.apache.shardingsphere.sql.parser.mysql.MySQLParserConfiguration
+org.apache.shardingsphere.sql.parser.mysql.MySQLParserFacade
diff --git a/shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-sql92/src/main/resources/META-INF/services/org.apache.shardingsphere.sql.parser.spi.SQLParserConfiguration b/shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-oracle/src/main/resources/META-INF/services/org.apache.shardingsphere.sql.parser.spi.SQLParserFacade
similarity index 92%
rename from shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-sql92/src/main/resources/META-INF/services/org.apache.shardingsphere.sql.parser.spi.SQLParserConfiguration
rename to shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-oracle/src/main/resources/META-INF/services/org.apache.shardingsphere.sql.parser.spi.SQLParserFacade
index 97b4cce..58cb61b 100644
--- a/shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-sql92/src/main/resources/META-INF/services/org.apache.shardingsphere.sql.parser.spi.SQLParserConfiguration
+++ b/shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-oracle/src/main/resources/META-INF/services/org.apache.shardingsphere.sql.parser.spi.SQLParserFacade
@@ -15,4 +15,4 @@
 # limitations under the License.
 #
 
-org.apache.shardingsphere.sql.parser.sql92.SQL92ParserConfiguration
+org.apache.shardingsphere.sql.parser.oracle.OracleParserFacade
diff --git a/shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-postgresql/src/main/resources/META-INF/services/org.apache.shardingsphere.sql.parser.spi.SQLParserConfiguration b/shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-postgresql/src/main/resources/META-INF/services/org.apache.shardingsphere.sql.parser.spi.SQLParserFacade
similarity index 98%
rename from shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-postgresql/src/main/resources/META-INF/services/org.apache.shardingsphere.sql.parser.spi.SQLParserConfiguration
rename to shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-postgresql/src/main/resources/META-INF/services/org.apache.shardingsphere.sql.parser.spi.SQLParserFacade
index 2d26aa7..2a9e279 100644
--- a/shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-postgresql/src/main/resources/META-INF/services/org.apache.shardingsphere.sql.parser.spi.SQLParserConfiguration
+++ b/shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-postgresql/src/main/resources/META-INF/services/org.apache.shardingsphere.sql.parser.spi.SQLParserFacade
@@ -15,4 +15,4 @@
 # limitations under the License.
 #
 
-org.apache.shardingsphere.sql.parser.postgresql.PostgreSQLParserConfiguration
+org.apache.shardingsphere.sql.parser.postgresql.PostgreSQLParserFacade
diff --git a/shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-oracle/src/main/resources/META-INF/services/org.apache.shardingsphere.sql.parser.spi.SQLParserConfiguration b/shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-sql92/src/main/resources/META-INF/services/org.apache.shardingsphere.sql.parser.spi.SQLParserFacade
similarity index 91%
rename from shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-oracle/src/main/resources/META-INF/services/org.apache.shardingsphere.sql.parser.spi.SQLParserConfiguration
rename to shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-sql92/src/main/resources/META-INF/services/org.apache.shardingsphere.sql.parser.spi.SQLParserFacade
index 5dd3c23..1a8f041 100644
--- a/shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-oracle/src/main/resources/META-INF/services/org.apache.shardingsphere.sql.parser.spi.SQLParserConfiguration
+++ b/shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-sql92/src/main/resources/META-INF/services/org.apache.shardingsphere.sql.parser.spi.SQLParserFacade
@@ -15,4 +15,4 @@
 # limitations under the License.
 #
 
-org.apache.shardingsphere.sql.parser.oracle.OracleParserConfiguration
+org.apache.shardingsphere.sql.parser.sql92.SQL92ParserFacade
diff --git a/shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-sqlserver/src/main/resources/META-INF/services/org.apache.shardingsphere.sql.parser.spi.SQLParserConfiguration b/shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-sqlserver/src/main/resources/META-INF/services/org.apache.shardingsphere.sql.parser.spi.SQLParserFacade
similarity index 91%
rename from shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-sqlserver/src/main/resources/META-INF/services/org.apache.shardingsphere.sql.parser.spi.SQLParserConfiguration
rename to shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-sqlserver/src/main/resources/META-INF/services/org.apache.shardingsphere.sql.parser.spi.SQLParserFacade
index d7b0cd5..325b8e6 100644
--- a/shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-sqlserver/src/main/resources/META-INF/services/org.apache.shardingsphere.sql.parser.spi.SQLParserConfiguration
+++ b/shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-sqlserver/src/main/resources/META-INF/services/org.apache.shardingsphere.sql.parser.spi.SQLParserFacade
@@ -15,4 +15,4 @@
 # limitations under the License.
 #
 
-org.apache.shardingsphere.sql.parser.sqlserver.SQLServerParserConfiguration
+org.apache.shardingsphere.sql.parser.sqlserver.SQLServerParserFacade
diff --git a/shardingsphere-sql-parser/shardingsphere-sql-parser-engine/src/main/java/org/apache/shardingsphere/sql/parser/core/parser/SQLParserFactory.java b/shardingsphere-sql-parser/shardingsphere-sql-parser-engine/src/main/java/org/apache/shardingsphere/sql/parser/core/parser/SQLParserFactory.java
index 0da6013..6a4b987 100644
--- a/shardingsphere-sql-parser/shardingsphere-sql-parser-engine/src/main/java/org/apache/shardingsphere/sql/parser/core/parser/SQLParserFactory.java
+++ b/shardingsphere-sql-parser/shardingsphere-sql-parser-engine/src/main/java/org/apache/shardingsphere/sql/parser/core/parser/SQLParserFactory.java
@@ -27,8 +27,8 @@ import org.antlr.v4.runtime.CommonTokenStream;
 import org.antlr.v4.runtime.Lexer;
 import org.antlr.v4.runtime.TokenStream;
 import org.apache.shardingsphere.sql.parser.api.parser.SQLParser;
-import org.apache.shardingsphere.sql.parser.core.SQLParserConfigurationRegistry;
-import org.apache.shardingsphere.sql.parser.spi.SQLParserConfiguration;
+import org.apache.shardingsphere.sql.parser.core.SQLParserFacadeRegistry;
+import org.apache.shardingsphere.sql.parser.spi.SQLParserFacade;
 
 import java.nio.CharBuffer;
 
@@ -46,11 +46,11 @@ public final class SQLParserFactory {
      * @return SQL parser
      */
     public static SQLParser newInstance(final String databaseTypeName, final String sql) {
-        return createSQLParser(sql, SQLParserConfigurationRegistry.getInstance().getSQLParserConfiguration(databaseTypeName));
+        return createSQLParser(sql, SQLParserFacadeRegistry.getInstance().getSQLParserFacade(databaseTypeName));
     }
     
     @SneakyThrows(ReflectiveOperationException.class)
-    private static SQLParser createSQLParser(final String sql, final SQLParserConfiguration config) {
+    private static SQLParser createSQLParser(final String sql, final SQLParserFacade config) {
         CodePointBuffer buffer = CodePointBuffer.withChars(CharBuffer.wrap(sql.toCharArray()));
         CodePointCharStream codePointCharStream = CodePointCharStream.fromBuffer(buffer);
         Lexer lexer = (Lexer) config.getLexerClass().getConstructor(CharStream.class).newInstance(codePointCharStream);
diff --git a/shardingsphere-sql-parser/shardingsphere-sql-parser-spi/src/main/java/org/apache/shardingsphere/sql/parser/spi/SQLVisitorFacade.java b/shardingsphere-sql-parser/shardingsphere-sql-parser-spi/src/main/java/org/apache/shardingsphere/sql/parser/spi/SQLVisitorFacade.java
index 4c60d18..a29c0e1 100644
--- a/shardingsphere-sql-parser/shardingsphere-sql-parser-spi/src/main/java/org/apache/shardingsphere/sql/parser/spi/SQLVisitorFacade.java
+++ b/shardingsphere-sql-parser/shardingsphere-sql-parser-spi/src/main/java/org/apache/shardingsphere/sql/parser/spi/SQLVisitorFacade.java
@@ -25,16 +25,16 @@ import org.apache.shardingsphere.sql.parser.api.visitor.SQLVisitor;
 public interface SQLVisitorFacade {
     
     /**
-     * Get name of database type.
+     * Get database type.
      *
-     * @return name of database type
+     * @return database type
      */
     String getDatabaseType();
     
     /**
-     * Get SQL visitor type.
+     * Get visitor type.
      *
-     * @return SQL visitor type
+     * @return visitor type
      */
     String getVisitorType();
diff --git a/shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-mysql/src/main/java/org/apache/shardingsphere/sql/parser/mysql/MySQLParserConfiguration.java b/shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-mysql/src/main/java/org/apache/shardingsphere/sql/parser/mysql/MySQLParserFacade.java
similarity index 85%
rename from shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-mysql/src/main/java/org/apache/shardingsphere/sql/parser/mysql/MySQLParserConfiguration.java
rename to shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-mysql/src/main/java/org/apache/shardingsphere/sql/parser/mysql/MySQLParserFacade.java
index d049bdb..56acf2b 100644
--- a/shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-mysql/src/main/java/org/apache/shardingsphere/sql/parser/mysql/MySQLParserConfiguration.java
+++ b/shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-mysql/src/main/java/org/apache/shardingsphere/sql/parser/mysql/MySQLParserFacade.java
@@ -21,15 +21,15 @@ import org.apache.shardingsphere.sql.parser.api.lexer.SQLLexer;
 import org.apache.shardingsphere.sql.parser.api.parser.SQLParser;
 import org.apache.shardingsphere.sql.parser.mysql.lexer.MySQLLexer;
 import org.apache.shardingsphere.sql.parser.mysql.parser.MySQLParser;
-import org.apache.shardingsphere.sql.parser.spi.SQLParserConfiguration;
+import org.apache.shardingsphere.sql.parser.spi.SQLParserFacade;
 
 /**
  * SQL parser configuration for MySQL.
  */
-public final class MySQLParserConfiguration implements SQLParserConfiguration {
+public final class MySQLParserFacade implements SQLParserFacade {
     
     @Override
-    public String getDatabaseTypeName() {
+    public String getDatabaseType() {
         return "MySQL";
     }
     
@@ -21,15 +21,15 @@ import org.apache.shardingsphere.sql.parser.api.lexer.SQLLexer;
 
 /**
- * SQL parser configuration for MySQL.
+ * SQL parser facade for MySQL.
  */
diff --git a/shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-oracle/src/main/java/org/apache/shardingsphere/sql/parser/oracle/OracleParserConfiguration.java b/shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-oracle/src/main/java/org/apache/shardingsphere/sql/parser/oracle/OracleParserFacade.java
similarity index 85%
rename from shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-oracle/src/main/java/org/apache/shardingsphere/sql/parser/oracle/OracleParserConfiguration.java
rename to shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-oracle/src/main/java/org/apache/shardingsphere/sql/parser/oracle/OracleParserFacade.java
index 156722c..7dc4fe3 100644
--- a/shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-oracle/src/main/java/org/apache/shardingsphere/sql/parser/oracle/OracleParserConfiguration.java
+++ b/shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-oracle/src/main/java/org/apache/shardingsphere/sql/parser/oracle/OracleParserFacade.java
@@ -21,15 +21,15 @@ import org.apache.shardingsphere.sql.parser.api.lexer.SQLLexer;
 import org.apache.shardingsphere.sql.parser.api.parser.SQLParser;
 import org.apache.shardingsphere.sql.parser.oracle.lexer.OracleLexer;
 import org.apache.shardingsphere.sql.parser.oracle.parser.OracleParser;
-import org.apache.shardingsphere.sql.parser.spi.SQLParserConfiguration;
+import org.apache.shardingsphere.sql.parser.spi.SQLParserFacade;
 
 /**
  * SQL parser configuration for Oracle.
  */
-public final class OracleParserConfiguration implements SQLParserConfiguration {
+public final class OracleParserFacade implements SQLParserFacade {
     
     @Override
-    public String getDatabaseTypeName() {
+    public String getDatabaseType() {
         return "Oracle";
     }
     
@@ -21,15 +21,15 @@ import org.apache.shardingsphere.sql.parser.api.lexer.SQLLexer;
 
 /**
- * SQL parser configuration for Oracle.
+ * SQL parser facade for Oracle.
  */
diff --git a/shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-postgresql/src/main/java/org/apache/shardingsphere/sql/parser/postgresql/PostgreSQLParserConfiguration.java b/shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-postgresql/src/main/java/org/apache/shardingsphere/sql/parser/postgresql/PostgreSQLParserFacade.java
similarity index 85%
rename from shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-postgresql/src/main/java/org/apache/shardingsphere/sql/parser/postgresql/PostgreSQLParserConfiguration.java
rename to shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-postgresql/src/main/java/org/apache/shardingsphere/sql/parser/postgresql/PostgreSQLParserFacade.java
index beb8927..f361865 100644
--- a/shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-postgresql/src/main/java/org/apache/shardingsphere/sql/parser/postgresql/PostgreSQLParserConfiguration.java
+++ b/shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-postgresql/src/main/java/org/apache/shardingsphere/sql/parser/postgresql/PostgreSQLParserFacade.java
@@ -21,15 +21,15 @@ import org.apache.shardingsphere.sql.parser.api.lexer.SQLLexer;
 import org.apache.shardingsphere.sql.parser.api.parser.SQLParser;
 import org.apache.shardingsphere.sql.parser.postgresql.lexer.PostgreSQLLexer;
 import org.apache.shardingsphere.sql.parser.postgresql.parser.PostgreSQLParser;
-import org.apache.shardingsphere.sql.parser.spi.SQLParserConfiguration;
+import org.apache.shardingsphere.sql.parser.spi.SQLParserFacade;
 
 /**
  * SQL parser configuration for PostgreSQL.
  */
-public final class PostgreSQLParserConfiguration implements SQLParserConfiguration {
+public final class PostgreSQLParserFacade implements SQLParserFacade {
     
     @Override
-    public String getDatabaseTypeName() {
+    public String getDatabaseType() {
         return "PostgreSQL";
     }
     
@@ -21,15 +21,15 @@ import org.apache.shardingsphere.sql.parser.api.lexer.SQLLexer;
 
 /**
- * SQL parser configuration for PostgreSQL.
+ * SQL parser facade for PostgreSQL.
  */
diff --git a/shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-sql92/src/main/java/org/apache/shardingsphere/sql/parser/sql92/SQL92ParserConfiguration.java b/shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-sql92/src/main/java/org/apache/shardingsphere/sql/parser/sql92/SQL92ParserFacade.java
similarity index 85%
rename from shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-sql92/src/main/java/org/apache/shardingsphere/sql/parser/sql92/SQL92ParserConfiguration.java
rename to shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-sql92/src/main/java/org/apache/shardingsphere/sql/parser/sql92/SQL92ParserFacade.java
index 9404528..b9b4c84 100644
--- a/shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-sql92/src/main/java/org/apache/shardingsphere/sql/parser/sql92/SQL92ParserConfiguration.java
+++ b/shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-sql92/src/main/java/org/apache/shardingsphere/sql/parser/sql92/SQL92ParserFacade.java
@@ -19,17 +19,17 @@ package org.apache.shardingsphere.sql.parser.sql92;
 
 import org.apache.shardingsphere.sql.parser.api.lexer.SQLLexer;
 import org.apache.shardingsphere.sql.parser.api.parser.SQLParser;
-import org.apache.shardingsphere.sql.parser.spi.SQLParserConfiguration;
+import org.apache.shardingsphere.sql.parser.spi.SQLParserFacade;
 import org.apache.shardingsphere.sql.parser.sql92.lexer.SQL92Lexer;
 import org.apache.shardingsphere.sql.parser.sql92.parser.SQL92Parser;
 
 /**
  * SQL parser configuration for SQL92.
  */
-public final class SQL92ParserConfiguration implements SQLParserConfiguration {
+public final class SQL92ParserFacade implements SQLParserFacade {
     
     @Override
-    public String getDatabaseTypeName() {
+    public String getDatabaseType() {
         return "SQL92";
     }
     
@@ -19,17 +19,17 @@ package org.apache.shardingsphere.sql.parser.sql92;
 
 /**
- * SQL parser configuration for SQL92.
+ * SQL parser facade for SQL92.
  */
diff --git a/shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-sqlserver/src/main/java/org/apache/shardingsphere/sql/parser/sqlserver/SQLServerParserConfiguration.java b/shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-sqlserver/src/main/java/org/apache/shardingsphere/sql/parser/sqlserver/SQLServerParserFacade.java
similarity index 85%
rename from shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-sqlserver/src/main/java/org/apache/shardingsphere/sql/parser/sqlserver/SQLServerParserConfiguration.java
rename to shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-sqlserver/src/main/java/org/apache/shardingsphere/sql/parser/sqlserver/SQLServerParserFacade.java
index e8b6945..035f190 100644
--- a/shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-sqlserver/src/main/java/org/apache/shardingsphere/sql/parser/sqlserver/SQLServerParserConfiguration.java
+++ b/shardingsphere-sql-parser/shardingsphere-sql-parser-dialect/shardingsphere-sql-parser-sqlserver/src/main/java/org/apache/shardingsphere/sql/parser/sqlserver/SQLServerParserFacade.java
@@ -19,17 +19,17 @@ package org.apache.shardingsphere.sql.parser.sqlserver;
 
 import org.apache.shardingsphere.sql.parser.api.lexer.SQLLexer;
 import org.apache.shardingsphere.sql.parser.api.parser.SQLParser;
-import org.apache.shardingsphere.sql.parser.spi.SQLParserConfiguration;
+import org.apache.shardingsphere.sql.parser.spi.SQLParserFacade;
 import org.apache.shardingsphere.sql.parser.sqlserver.lexer.SQLServerLexer;
 import org.apache.shardingsphere.sql.parser.sqlserver.parser.SQLServerParser;
 
 /**
  * SQL parser configuration for SQLServer.
  */
-public final class SQLServerParserConfiguration implements SQLParserConfiguration {
+public final class SQLServerParserFacade implements SQLParserFacade {
     
     @Override
-    public String getDatabaseTypeName() {
+    public String getDatabaseType() {
         return "SQLServer";
     }
     
@@ -19,17 +19,17 @@ package org.apache.shardingsphere.sql.parser.sqlserver;
 
 /**
- * SQL parser configuration for SQLServer.
+ * SQL parser facade for SQLServer.
  */
diff --git a/shardingsphere-sql-parser/shardingsphere-sql-parser-engine/src/main/java/org/apache/shardingsphere/sql/parser/core/SQLParserConfigurationRegistry.java b/shardingsphere-sql-parser/shardingsphere-sql-parser-engine/src/main/java/org/apache/shardingsphere/sql/parser/core/SQLParserFacadeRegistry.java
similarity index 53%
rename from shardingsphere-sql-parser/shardingsphere-sql-parser-engine/src/main/java/org/apache/shardingsphere/sql/parser/core/SQLParserConfigurationRegistry.java
rename to shardingsphere-sql-parser/shardingsphere-sql-parser-engine/src/main/java/org/apache/shardingsphere/sql/parser/core/SQLParserFacadeRegistry.java
index 3076143..126c356 100644
--- a/shardingsphere-sql-parser/shardingsphere-sql-parser-engine/src/main/java/org/apache/shardingsphere/sql/parser/core/SQLParserConfigurationRegistry.java
+++ b/shardingsphere-sql-parser/shardingsphere-sql-parser-engine/src/main/java/org/apache/shardingsphere/sql/parser/core/SQLParserFacadeRegistry.java
@@ -17,25 +17,25 @@
 
 package org.apache.shardingsphere.sql.parser.core;
 
-import org.apache.shardingsphere.sql.parser.spi.SQLParserConfiguration;
+import org.apache.shardingsphere.sql.parser.spi.SQLParserFacade;
 
 import java.util.HashMap;
 import java.util.Map;
 import java.util.ServiceLoader;
 
 /**
  * SQL parser configuration registry.
  */
-public final class SQLParserConfigurationRegistry {
+public final class SQLParserFacadeRegistry {
     
-    private static final SQLParserConfigurationRegistry INSTANCE = new SQLParserConfigurationRegistry();
+    private static final SQLParserFacadeRegistry INSTANCE = new SQLParserFacadeRegistry();
     
-    private final Map<String, SQLParserConfiguration> configurations;
+    private final Map<String, SQLParserFacade> facades;
     
-    private SQLParserConfigurationRegistry() {
-        configurations = new HashMap<>();
-        for (SQLParserConfiguration each : ServiceLoader.load(SQLParserConfiguration.class)) {
-            configurations.put(each.getDatabaseTypeName(), each);
+    private SQLParserFacadeRegistry() {
+        facades = new HashMap<>();
+        for (SQLParserFacade each : ServiceLoader.load(SQLParserFacade.class)) {
+            facades.put(each.getDatabaseType(), each);
         }
     }
     
@@ -44,20 +44,20 @@ public final class SQLParserConfigurationRegistry {
      *
      * @return instance
      */
-    public static SQLParserConfigurationRegistry getInstance() {
+    public static SQLParserFacadeRegistry getInstance() {
         return INSTANCE;
     }
     
     /**
      * Get SQL parser configuration.
      * 
      * @param databaseTypeName database type name
      * @return SQL parser configuration
      */
-    public SQLParserConfiguration getSQLParserConfiguration(final String databaseTypeName) {
-        if (configurations.containsKey(databaseTypeName)) {
-            return configurations.get(databaseTypeName);
+    public SQLParserFacade getSQLParserFacade(final String databaseType) {
+        if (facades.containsKey(databaseType)) {
+            return facades.get(databaseType);
         }
-        throw new UnsupportedOperationException(String.format("Cannot support database type '%s'", databaseTypeName));
+        throw new UnsupportedOperationException(String.format("Cannot support database type '%s'", databaseType));
     }
 }
@@ -17,25 +17,25 @@
 
 /**
- * SQL parser configuration registry.
+ * SQL parser facade registry.
  */
@@ -44,20 +44,20 @@ public final class SQLParserConfigurationRegistry {
     
     /**
-     * Get SQL parser configuration.
+     * Get SQL parser facade.
      * 
@@ -44,20 +44,20 @@ public final class SQLParserConfigurationRegistry {
      * 
-     * @param databaseTypeName database type name
-     * @return SQL parser configuration
+     * @param databaseType database type
+     * @return SQL parser facade
      */
diff --git a/shardingsphere-sql-parser/shardingsphere-sql-parser-spi/src/main/java/org/apache/shardingsphere/sql/parser/spi/SQLParserConfiguration.java b/shardingsphere-sql-parser/shardingsphere-sql-parser-spi/src/main/java/org/apache/shardingsphere/sql/parser/spi/SQLParserFacade.java
similarity index 88%
rename from shardingsphere-sql-parser/shardingsphere-sql-parser-spi/src/main/java/org/apache/shardingsphere/sql/parser/spi/SQLParserConfiguration.java
rename to shardingsphere-sql-parser/shardingsphere-sql-parser-spi/src/main/java/org/apache/shardingsphere/sql/parser/spi/SQLParserFacade.java
index 550a544..64e17d6 100644
--- a/shardingsphere-sql-parser/shardingsphere-sql-parser-spi/src/main/java/org/apache/shardingsphere/sql/parser/spi/SQLParserConfiguration.java
+++ b/shardingsphere-sql-parser/shardingsphere-sql-parser-spi/src/main/java/org/apache/shardingsphere/sql/parser/spi/SQLParserFacade.java
@@ -21,16 +21,16 @@ import org.apache.shardingsphere.sql.parser.api.lexer.SQLLexer;
 import org.apache.shardingsphere.sql.parser.api.parser.SQLParser;
 
 /**
  * SQL parser configuration.
  */
-public interface SQLParserConfiguration {
+public interface SQLParserFacade {
     
     /**
-     * Get name of database type.
+     * Get database type.
      *
-     * @return name of database type
+     * @return database type
      */
-    String getDatabaseTypeName();
+    String getDatabaseType();
     
     /**
      * Get SQL lexer class type.
@@ -21,16 +21,16 @@ import org.apache.shardingsphere.sql.parser.api.lexer.SQLLexer;
 
 /**
- * SQL parser configuration.
+ * SQL parser facade.
  */